/* 
 * i-scream central monitoring system
 * http://www.i-scream.org
 * Copyright (C) 2000-2002 i-scream
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

//---PACKAGE DECLARATION---
package uk.org.iscream.cms.server.filter.plugins;

//---IMPORTS---
import uk.org.iscream.cms.server.filter.PluginServiceCheck;
import java.net.URL;
import java.net.HttpURLConnection;

/**
 * Tests whether a webserver is responding on port 80.
 * Connects on port 80 and performs a simple HTTP HEAD request.
 * Currently it sends back 200 for OK, anything else indicates a failure.
 *
 * @author  $Author: tdb $
 * @version $Id: HTTP__ServiceCheck.java,v 1.12 2004/08/01 10:41:02 tdb Exp $
 */
public class HTTP__ServiceCheck implements PluginServiceCheck {

//---FINAL ATTRIBUTES---

    /**
     * The current CVS revision of this class
     */
    public final String REVISION = "$Revision: 1.12 $";
    
    public final String DESC = "Checks that a webserver is responding to requests.";
    
//---STATIC METHODS---

//---CONSTRUCTORS---

//---PUBLIC METHODS---

    /**
     * Performs the service check on a given host.
     *
     * @param hostname the host to check
     * @return XML data representing the result of the test
     */
    public String runServiceCheck(String hostname){
        String status = "";
        String message = "";
        try {
            HttpURLConnection connection = (HttpURLConnection) ((new URL("HTTP://" + hostname)).openConnection());
            // only get the head as we don't want any real content
            connection.setRequestMethod("HEAD");
            // let the server know who we are, just to be nice, and get our name about ;p
            connection.setRequestProperty("User-Agent", "i-scream HTTP Service Checker v" + REVISION.substring(11, REVISION.length() - 2));
            // connect and do the request
            connection.connect();
            if (connection.getResponseCode() == 200 ) {
                status = "0";
            } else {
                status = "1";
            }
            message = connection.getResponseMessage();
            connection.disconnect();
        } catch (Exception e) {
            status = "1";
            message = "Service check failed to establish connection to host:" + e.getMessage();
       }
        // send the results back
        return "<HTTP status=\"" + status + "\" message=\"" + message + "\"></HTTP>";
    }

    /**
     * return the String representation of what the filter does
     */
    public String getDescription(){
        return DESC;
    }

//---PRIVATE METHODS---

//---ACCESSOR/MUTATOR METHODS---

//---ATTRIBUTES---

//---STATIC ATTRIBUTES---

}
